# -*- coding: utf-8 -*-

from twisted.web.client import getPage
from twisted.internet import defer
from simplejson import loads as json_loads
import logging

log = logging.getLogger("nozbe")

class NozbeLoader(object):
    
    def __init__(self, api_key):
        self.key = api_key
    def get_projects(self):
        return self._make_request("projects")
    def get_contexts(self):
        return self._make_request("contexts")
    def get_project_actions(self, project_id):
        return self._make_request("actions", "what-project", id = project_id)
    
    @defer.inlineCallbacks
    def _make_request(self, *call_items, **params):
        """
        Generuje żądanie do Nozbe.
                
        @param call_items: projects, context albo i actions, what-context
        @param args: ewentualne specyficzne parametry, np id=cos
        """
        parts = ["http://www.nozbe.com/api"] + list(call_items) \
            + [ ("%s-%s" % (key, value)) for key, value in params.iteritems() ] \
            + [ "key-%s" % self.key ]
        url = "/".join(parts)        
        if type(url) == unicode:
            url = url.encode("utf-8")
        log.debug("Calling " + url)
        reply = yield getPage(url)
        if not reply:
            raise Exception("Can not load data from Nozbe. Wrong API key?")
        log.debug("Reply: " + reply)
        data = json_loads(reply)
        defer.returnValue(data)
